# Installation

## Stable release

To install gerbyx, run this command in your terminal:

```sh
uv add gerbyx
```

Or if you prefer to use `pip`:

```sh
pip install gerbyx
```

## From source

The source files for gerbyx can be downloaded from the [Github repo](https://github.com/TheAntTeam/gerbyx).

You can either clone the public repository:

```sh
git clone git://github.com/TheAntTeam/gerbyx
```

Once you have a copy of the source, you can install it with:

```sh
cd gerbyx
uv pip install .
```
